# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
- Created the project

## [0.0.1] - 2024-10-05
### Added
- Initial release

## [0.0.2] - 2024-10-05
### Added
- Added CHANGELOG.md

### Changed
- Updated README.md

## [0.0.3] - 2024-10-08
### Changed
- Refactor BaseConfig

## [0.0.4] - 2024-10-13
### Changed
- Add support for UnionType when converting dict to AttrDict object

## [0.0.4] - 2024-10-13
### Changed
- Fix UnionType import error

<!-- future template
## [0.0.X] - YYYY-MM-DD
### Added
- 

### Changed
- 

### Deprecated
- 

### Removed
- 

### Fixed
- 

### Security
- 
-->